// Copyright 2021 Google LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#[derive(Clone, PartialEq, Debug)]
pub struct True();
#[derive(Clone, PartialEq, Debug)]
pub struct False();

pub trait BoolType {
    type Choose<T, F>;
}
impl BoolType for True {
    type Choose<T, F> = T;
}
impl BoolType for False {
    type Choose<T, F> = F;
}
